@@ -17,24 +17,25 @@
 )]
 //! A simple database system that allows the use of multiple different backends.
 
-use serde::{de::DeserializeOwned, Serialize};
-use std::fmt::Debug;
-
 pub mod backend;
 mod database;
+mod entry;
 pub mod error;
 pub mod gateway;
 
-/// A marker trait for use within the [`Database`].
-///
-/// This signifies that the type can be stored within a [`Database`].
-pub trait Settings: Serialize + DeserializeOwned + Debug {}
-
-impl<T> Settings for T where T: Serialize + DeserializeOwned + Debug {}
-
-pub use self::database::Database;
+pub use self::{
+    database::Database,
+    entry::{Key, Settings},
+};
 #[doc(inline)]
 pub use self::{error::ChartError as Error, gateway::Gateway};
 
 /// A type alias for a [`Result`] that wraps around [`Error`].
-pub type ChartResult<T> = Result<T, Error>;
+pub type ChartResult<T, B> = Result<T, Error<B>>;
+
+/// The helper derive macro for easily implementing [`Key`].
+///
+/// [`Key`]: crate::Key
+#[cfg(feature = "derive")]
+#[doc(cfg(feature = "derive"))]
+pub use starchart_derive::Key;
